this is a plugin from https://github.com/pyblish/pyblish-starter/blob/master/pyblish_starter/plugins/validate_normals.py
it checks if meshes don't have locked normals
since this is written with cmds isntead of pymel, it requires meshnames from a collector